# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: routerrpc/router.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from lnrpc import rpc_pb2 as lnrpc_dot_rpc__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='routerrpc/router.proto',
  package='routerrpc',
  syntax='proto3',
  serialized_options=_b('Z.github.com/lncm/lnd-rpc/v0.8.2/lnrpc/routerrpc'),
  serialized_pb=_b('\n\x16routerrpc/router.proto\x12\trouterrpc\x1a\x0flnrpc/rpc.proto\"\xf8\x02\n\x12SendPaymentRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0b\n\x03\x61mt\x18\x02 \x01(\x03\x12\x14\n\x0cpayment_hash\x18\x03 \x01(\x0c\x12\x18\n\x10\x66inal_cltv_delta\x18\x04 \x01(\x05\x12\x17\n\x0fpayment_request\x18\x05 \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x06 \x01(\x05\x12\x15\n\rfee_limit_sat\x18\x07 \x01(\x03\x12\x18\n\x10outgoing_chan_id\x18\x08 \x01(\x04\x12\x12\n\ncltv_limit\x18\t \x01(\x05\x12\x32\n\x0broute_hints\x18\n \x03(\x0b\x32\x10.lnrpc.RouteHintR\x0broute_hints\x12<\n\x08\x64\x65st_tlv\x18\x0b \x03(\x0b\x32*.routerrpc.SendPaymentRequest.DestTlvEntry\x1a.\n\x0c\x44\x65stTlvEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x13TrackPaymentRequest\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\x0c\"f\n\rPaymentStatus\x12&\n\x05state\x18\x01 \x01(\x0e\x32\x17.routerrpc.PaymentState\x12\x10\n\x08preimage\x18\x02 \x01(\x0c\x12\x1b\n\x05route\x18\x03 \x01(\x0b\x32\x0c.lnrpc.Route\"0\n\x0fRouteFeeRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61mt_sat\x18\x02 \x01(\x03\"E\n\x10RouteFeeResponse\x12\x18\n\x10routing_fee_msat\x18\x01 \x01(\x03\x12\x17\n\x0ftime_lock_delay\x18\x02 \x01(\x03\"G\n\x12SendToRouteRequest\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\x0c\x12\x1b\n\x05route\x18\x02 \x01(\x0b\x32\x0c.lnrpc.Route\"L\n\x13SendToRouteResponse\x12\x10\n\x08preimage\x18\x01 \x01(\x0c\x12#\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x12.routerrpc.Failure\"\x9a\x07\n\x07\x46\x61ilure\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x1e.routerrpc.Failure.FailureCode\x12\x30\n\x0e\x63hannel_update\x18\x03 \x01(\x0b\x32\x18.routerrpc.ChannelUpdate\x12\x11\n\thtlc_msat\x18\x04 \x01(\x04\x12\x15\n\ronion_sha_256\x18\x05 \x01(\x0c\x12\x13\n\x0b\x63ltv_expiry\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x1c\n\x14\x66\x61ilure_source_index\x18\x08 \x01(\r\x12\x0e\n\x06height\x18\t \x01(\r\"\xac\x05\n\x0b\x46\x61ilureCode\x12\x0c\n\x08RESERVED\x10\x00\x12(\n$INCORRECT_OR_UNKNOWN_PAYMENT_DETAILS\x10\x01\x12\x1c\n\x18INCORRECT_PAYMENT_AMOUNT\x10\x02\x12\x1f\n\x1b\x46INAL_INCORRECT_CLTV_EXPIRY\x10\x03\x12\x1f\n\x1b\x46INAL_INCORRECT_HTLC_AMOUNT\x10\x04\x12\x19\n\x15\x46INAL_EXPIRY_TOO_SOON\x10\x05\x12\x11\n\rINVALID_REALM\x10\x06\x12\x13\n\x0f\x45XPIRY_TOO_SOON\x10\x07\x12\x19\n\x15INVALID_ONION_VERSION\x10\x08\x12\x16\n\x12INVALID_ONION_HMAC\x10\t\x12\x15\n\x11INVALID_ONION_KEY\x10\n\x12\x18\n\x14\x41MOUNT_BELOW_MINIMUM\x10\x0b\x12\x14\n\x10\x46\x45\x45_INSUFFICIENT\x10\x0c\x12\x19\n\x15INCORRECT_CLTV_EXPIRY\x10\r\x12\x14\n\x10\x43HANNEL_DISABLED\x10\x0e\x12\x1d\n\x19TEMPORARY_CHANNEL_FAILURE\x10\x0f\x12!\n\x1dREQUIRED_NODE_FEATURE_MISSING\x10\x10\x12$\n REQUIRED_CHANNEL_FEATURE_MISSING\x10\x11\x12\x15\n\x11UNKNOWN_NEXT_PEER\x10\x12\x12\x1a\n\x16TEMPORARY_NODE_FAILURE\x10\x13\x12\x1a\n\x16PERMANENT_NODE_FAILURE\x10\x14\x12\x1d\n\x19PERMANENT_CHANNEL_FAILURE\x10\x15\x12\x12\n\x0e\x45XPIRY_TOO_FAR\x10\x16\x12\x14\n\x0fUNKNOWN_FAILURE\x10\xe6\x07\x12\x17\n\x12UNREADABLE_FAILURE\x10\xe7\x07J\x04\x08\x02\x10\x03\"\x96\x02\n\rChannelUpdate\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12\x12\n\nchain_hash\x18\x02 \x01(\x0c\x12\x0f\n\x07\x63han_id\x18\x03 \x01(\x04\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x12\x15\n\rmessage_flags\x18\n \x01(\r\x12\x15\n\rchannel_flags\x18\x05 \x01(\r\x12\x17\n\x0ftime_lock_delta\x18\x06 \x01(\r\x12\x19\n\x11htlc_minimum_msat\x18\x07 \x01(\x04\x12\x10\n\x08\x62\x61se_fee\x18\x08 \x01(\r\x12\x10\n\x08\x66\x65\x65_rate\x18\t \x01(\r\x12\x19\n\x11htlc_maximum_msat\x18\x0b \x01(\x04\x12\x19\n\x11\x65xtra_opaque_data\x18\x0c \x01(\x0c\"\x1c\n\x1aResetMissionControlRequest\"\x1d\n\x1bResetMissionControlResponse\"\x1c\n\x1aQueryMissionControlRequest\"y\n\x1bQueryMissionControlResponse\x12,\n\x05nodes\x18\x01 \x03(\x0b\x32\x16.routerrpc.NodeHistoryR\x05nodes\x12,\n\x05pairs\x18\x02 \x03(\x0b\x32\x16.routerrpc.PairHistoryR\x05pairs\"\x83\x01\n\x0bNodeHistory\x12\x16\n\x06pubkey\x18\x01 \x01(\x0cR\x06pubkey\x12&\n\x0elast_fail_time\x18\x02 \x01(\x03R\x0elast_fail_time\x12.\n\x12other_success_prob\x18\x03 \x01(\x02R\x12other_success_probJ\x04\x08\x04\x10\x05\"\xf5\x01\n\x0bPairHistory\x12\x1c\n\tnode_from\x18\x01 \x01(\x0cR\tnode_from\x12\x18\n\x07node_to\x18\x02 \x01(\x0cR\x07node_to\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\x12\x32\n\x14min_penalize_amt_sat\x18\x04 \x01(\x03R\x14min_penalize_amt_sat\x12\"\n\x0csuccess_prob\x18\x05 \x01(\x02R\x0csuccess_prob\x12\x38\n\x17last_attempt_successful\x18\x06 \x01(\x08R\x17last_attempt_successful\"n\n\x11\x42uildRouteRequest\x12\x10\n\x08\x61mt_msat\x18\x01 \x01(\x03\x12\x18\n\x10\x66inal_cltv_delta\x18\x02 \x01(\x05\x12\x18\n\x10outgoing_chan_id\x18\x03 \x01(\x04\x12\x13\n\x0bhop_pubkeys\x18\x04 \x03(\x0c\"1\n\x12\x42uildRouteResponse\x12\x1b\n\x05route\x18\x01 \x01(\x0b\x32\x0c.lnrpc.Route*\x8d\x01\n\x0cPaymentState\x12\r\n\tIN_FLIGHT\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\x12\n\x0e\x46\x41ILED_TIMEOUT\x10\x02\x12\x13\n\x0f\x46\x41ILED_NO_ROUTE\x10\x03\x12\x10\n\x0c\x46\x41ILED_ERROR\x10\x04\x12$\n FAILED_INCORRECT_PAYMENT_DETAILS\x10\x05\x32\xd0\x04\n\x06Router\x12H\n\x0bSendPayment\x12\x1d.routerrpc.SendPaymentRequest\x1a\x18.routerrpc.PaymentStatus0\x01\x12J\n\x0cTrackPayment\x12\x1e.routerrpc.TrackPaymentRequest\x1a\x18.routerrpc.PaymentStatus0\x01\x12K\n\x10\x45stimateRouteFee\x12\x1a.routerrpc.RouteFeeRequest\x1a\x1b.routerrpc.RouteFeeResponse\x12L\n\x0bSendToRoute\x12\x1d.routerrpc.SendToRouteRequest\x1a\x1e.routerrpc.SendToRouteResponse\x12\x64\n\x13ResetMissionControl\x12%.routerrpc.ResetMissionControlRequest\x1a&.routerrpc.ResetMissionControlResponse\x12\x64\n\x13QueryMissionControl\x12%.routerrpc.QueryMissionControlRequest\x1a&.routerrpc.QueryMissionControlResponse\x12I\n\nBuildRoute\x12\x1c.routerrpc.BuildRouteRequest\x1a\x1d.routerrpc.BuildRouteResponseB0Z.github.com/lncm/lnd-rpc/v0.8.2/lnrpc/routerrpcb\x06proto3')
  ,
  dependencies=[lnrpc_dot_rpc__pb2.DESCRIPTOR,])

_PAYMENTSTATE = _descriptor.EnumDescriptor(
  name='PaymentState',
  full_name='routerrpc.PaymentState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IN_FLIGHT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_NO_ROUTE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_INCORRECT_PAYMENT_DETAILS', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2820,
  serialized_end=2961,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTSTATE)

PaymentState = enum_type_wrapper.EnumTypeWrapper(_PAYMENTSTATE)
IN_FLIGHT = 0
SUCCEEDED = 1
FAILED_TIMEOUT = 2
FAILED_NO_ROUTE = 3
FAILED_ERROR = 4
FAILED_INCORRECT_PAYMENT_DETAILS = 5


_FAILURE_FAILURECODE = _descriptor.EnumDescriptor(
  name='FailureCode',
  full_name='routerrpc.Failure.FailureCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCORRECT_OR_UNKNOWN_PAYMENT_DETAILS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCORRECT_PAYMENT_AMOUNT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_INCORRECT_CLTV_EXPIRY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_INCORRECT_HTLC_AMOUNT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_EXPIRY_TOO_SOON', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REALM', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRY_TOO_SOON', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ONION_VERSION', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ONION_HMAC', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ONION_KEY', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AMOUNT_BELOW_MINIMUM', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEE_INSUFFICIENT', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCORRECT_CLTV_EXPIRY', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_DISABLED', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPORARY_CHANNEL_FAILURE', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUIRED_NODE_FEATURE_MISSING', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUIRED_CHANNEL_FEATURE_MISSING', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_NEXT_PEER', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPORARY_NODE_FAILURE', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_NODE_FAILURE', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_CHANNEL_FAILURE', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRY_TOO_FAR', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FAILURE', index=23, number=998,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNREADABLE_FAILURE', index=24, number=999,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1087,
  serialized_end=1771,
)
_sym_db.RegisterEnumDescriptor(_FAILURE_FAILURECODE)


_SENDPAYMENTREQUEST_DESTTLVENTRY = _descriptor.Descriptor(
  name='DestTlvEntry',
  full_name='routerrpc.SendPaymentRequest.DestTlvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='routerrpc.SendPaymentRequest.DestTlvEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='routerrpc.SendPaymentRequest.DestTlvEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=431,
)

_SENDPAYMENTREQUEST = _descriptor.Descriptor(
  name='SendPaymentRequest',
  full_name='routerrpc.SendPaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.SendPaymentRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amt', full_name='routerrpc.SendPaymentRequest.amt', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.SendPaymentRequest.payment_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_cltv_delta', full_name='routerrpc.SendPaymentRequest.final_cltv_delta', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='routerrpc.SendPaymentRequest.payment_request', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout_seconds', full_name='routerrpc.SendPaymentRequest.timeout_seconds', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_limit_sat', full_name='routerrpc.SendPaymentRequest.fee_limit_sat', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outgoing_chan_id', full_name='routerrpc.SendPaymentRequest.outgoing_chan_id', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cltv_limit', full_name='routerrpc.SendPaymentRequest.cltv_limit', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route_hints', full_name='routerrpc.SendPaymentRequest.route_hints', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='route_hints', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dest_tlv', full_name='routerrpc.SendPaymentRequest.dest_tlv', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SENDPAYMENTREQUEST_DESTTLVENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=431,
)


_TRACKPAYMENTREQUEST = _descriptor.Descriptor(
  name='TrackPaymentRequest',
  full_name='routerrpc.TrackPaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.TrackPaymentRequest.payment_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=476,
)


_PAYMENTSTATUS = _descriptor.Descriptor(
  name='PaymentStatus',
  full_name='routerrpc.PaymentStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='routerrpc.PaymentStatus.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.PaymentStatus.preimage', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.PaymentStatus.route', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=580,
)


_ROUTEFEEREQUEST = _descriptor.Descriptor(
  name='RouteFeeRequest',
  full_name='routerrpc.RouteFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.RouteFeeRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amt_sat', full_name='routerrpc.RouteFeeRequest.amt_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=630,
)


_ROUTEFEERESPONSE = _descriptor.Descriptor(
  name='RouteFeeResponse',
  full_name='routerrpc.RouteFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_fee_msat', full_name='routerrpc.RouteFeeResponse.routing_fee_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_lock_delay', full_name='routerrpc.RouteFeeResponse.time_lock_delay', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=701,
)


_SENDTOROUTEREQUEST = _descriptor.Descriptor(
  name='SendToRouteRequest',
  full_name='routerrpc.SendToRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.SendToRouteRequest.payment_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.SendToRouteRequest.route', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=774,
)


_SENDTOROUTERESPONSE = _descriptor.Descriptor(
  name='SendToRouteResponse',
  full_name='routerrpc.SendToRouteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.SendToRouteResponse.preimage', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='routerrpc.SendToRouteResponse.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=852,
)


_FAILURE = _descriptor.Descriptor(
  name='Failure',
  full_name='routerrpc.Failure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='routerrpc.Failure.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_update', full_name='routerrpc.Failure.channel_update', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='htlc_msat', full_name='routerrpc.Failure.htlc_msat', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onion_sha_256', full_name='routerrpc.Failure.onion_sha_256', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cltv_expiry', full_name='routerrpc.Failure.cltv_expiry', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='routerrpc.Failure.flags', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure_source_index', full_name='routerrpc.Failure.failure_source_index', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='routerrpc.Failure.height', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FAILURE_FAILURECODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=1777,
)


_CHANNELUPDATE = _descriptor.Descriptor(
  name='ChannelUpdate',
  full_name='routerrpc.ChannelUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='routerrpc.ChannelUpdate.signature', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_hash', full_name='routerrpc.ChannelUpdate.chain_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chan_id', full_name='routerrpc.ChannelUpdate.chan_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='routerrpc.ChannelUpdate.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_flags', full_name='routerrpc.ChannelUpdate.message_flags', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_flags', full_name='routerrpc.ChannelUpdate.channel_flags', index=5,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_lock_delta', full_name='routerrpc.ChannelUpdate.time_lock_delta', index=6,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='htlc_minimum_msat', full_name='routerrpc.ChannelUpdate.htlc_minimum_msat', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_fee', full_name='routerrpc.ChannelUpdate.base_fee', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_rate', full_name='routerrpc.ChannelUpdate.fee_rate', index=9,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='htlc_maximum_msat', full_name='routerrpc.ChannelUpdate.htlc_maximum_msat', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_opaque_data', full_name='routerrpc.ChannelUpdate.extra_opaque_data', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1780,
  serialized_end=2058,
)


_RESETMISSIONCONTROLREQUEST = _descriptor.Descriptor(
  name='ResetMissionControlRequest',
  full_name='routerrpc.ResetMissionControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2060,
  serialized_end=2088,
)


_RESETMISSIONCONTROLRESPONSE = _descriptor.Descriptor(
  name='ResetMissionControlResponse',
  full_name='routerrpc.ResetMissionControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2090,
  serialized_end=2119,
)


_QUERYMISSIONCONTROLREQUEST = _descriptor.Descriptor(
  name='QueryMissionControlRequest',
  full_name='routerrpc.QueryMissionControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2149,
)


_QUERYMISSIONCONTROLRESPONSE = _descriptor.Descriptor(
  name='QueryMissionControlResponse',
  full_name='routerrpc.QueryMissionControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='routerrpc.QueryMissionControlResponse.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='routerrpc.QueryMissionControlResponse.pairs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pairs', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2151,
  serialized_end=2272,
)


_NODEHISTORY = _descriptor.Descriptor(
  name='NodeHistory',
  full_name='routerrpc.NodeHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='routerrpc.NodeHistory.pubkey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubkey', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_fail_time', full_name='routerrpc.NodeHistory.last_fail_time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='last_fail_time', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='other_success_prob', full_name='routerrpc.NodeHistory.other_success_prob', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='other_success_prob', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2275,
  serialized_end=2406,
)


_PAIRHISTORY = _descriptor.Descriptor(
  name='PairHistory',
  full_name='routerrpc.PairHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_from', full_name='routerrpc.PairHistory.node_from', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_from', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_to', full_name='routerrpc.PairHistory.node_to', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node_to', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='routerrpc.PairHistory.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_penalize_amt_sat', full_name='routerrpc.PairHistory.min_penalize_amt_sat', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='min_penalize_amt_sat', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success_prob', full_name='routerrpc.PairHistory.success_prob', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='success_prob', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_attempt_successful', full_name='routerrpc.PairHistory.last_attempt_successful', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='last_attempt_successful', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2409,
  serialized_end=2654,
)


_BUILDROUTEREQUEST = _descriptor.Descriptor(
  name='BuildRouteRequest',
  full_name='routerrpc.BuildRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amt_msat', full_name='routerrpc.BuildRouteRequest.amt_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_cltv_delta', full_name='routerrpc.BuildRouteRequest.final_cltv_delta', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outgoing_chan_id', full_name='routerrpc.BuildRouteRequest.outgoing_chan_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hop_pubkeys', full_name='routerrpc.BuildRouteRequest.hop_pubkeys', index=3,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2656,
  serialized_end=2766,
)


_BUILDROUTERESPONSE = _descriptor.Descriptor(
  name='BuildRouteResponse',
  full_name='routerrpc.BuildRouteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.BuildRouteResponse.route', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2768,
  serialized_end=2817,
)

_SENDPAYMENTREQUEST_DESTTLVENTRY.containing_type = _SENDPAYMENTREQUEST
_SENDPAYMENTREQUEST.fields_by_name['route_hints'].message_type = lnrpc_dot_rpc__pb2._ROUTEHINT
_SENDPAYMENTREQUEST.fields_by_name['dest_tlv'].message_type = _SENDPAYMENTREQUEST_DESTTLVENTRY
_PAYMENTSTATUS.fields_by_name['state'].enum_type = _PAYMENTSTATE
_PAYMENTSTATUS.fields_by_name['route'].message_type = lnrpc_dot_rpc__pb2._ROUTE
_SENDTOROUTEREQUEST.fields_by_name['route'].message_type = lnrpc_dot_rpc__pb2._ROUTE
_SENDTOROUTERESPONSE.fields_by_name['failure'].message_type = _FAILURE
_FAILURE.fields_by_name['code'].enum_type = _FAILURE_FAILURECODE
_FAILURE.fields_by_name['channel_update'].message_type = _CHANNELUPDATE
_FAILURE_FAILURECODE.containing_type = _FAILURE
_QUERYMISSIONCONTROLRESPONSE.fields_by_name['nodes'].message_type = _NODEHISTORY
_QUERYMISSIONCONTROLRESPONSE.fields_by_name['pairs'].message_type = _PAIRHISTORY
_BUILDROUTERESPONSE.fields_by_name['route'].message_type = lnrpc_dot_rpc__pb2._ROUTE
DESCRIPTOR.message_types_by_name['SendPaymentRequest'] = _SENDPAYMENTREQUEST
DESCRIPTOR.message_types_by_name['TrackPaymentRequest'] = _TRACKPAYMENTREQUEST
DESCRIPTOR.message_types_by_name['PaymentStatus'] = _PAYMENTSTATUS
DESCRIPTOR.message_types_by_name['RouteFeeRequest'] = _ROUTEFEEREQUEST
DESCRIPTOR.message_types_by_name['RouteFeeResponse'] = _ROUTEFEERESPONSE
DESCRIPTOR.message_types_by_name['SendToRouteRequest'] = _SENDTOROUTEREQUEST
DESCRIPTOR.message_types_by_name['SendToRouteResponse'] = _SENDTOROUTERESPONSE
DESCRIPTOR.message_types_by_name['Failure'] = _FAILURE
DESCRIPTOR.message_types_by_name['ChannelUpdate'] = _CHANNELUPDATE
DESCRIPTOR.message_types_by_name['ResetMissionControlRequest'] = _RESETMISSIONCONTROLREQUEST
DESCRIPTOR.message_types_by_name['ResetMissionControlResponse'] = _RESETMISSIONCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['QueryMissionControlRequest'] = _QUERYMISSIONCONTROLREQUEST
DESCRIPTOR.message_types_by_name['QueryMissionControlResponse'] = _QUERYMISSIONCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['NodeHistory'] = _NODEHISTORY
DESCRIPTOR.message_types_by_name['PairHistory'] = _PAIRHISTORY
DESCRIPTOR.message_types_by_name['BuildRouteRequest'] = _BUILDROUTEREQUEST
DESCRIPTOR.message_types_by_name['BuildRouteResponse'] = _BUILDROUTERESPONSE
DESCRIPTOR.enum_types_by_name['PaymentState'] = _PAYMENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendPaymentRequest = _reflection.GeneratedProtocolMessageType('SendPaymentRequest', (_message.Message,), dict(

  DestTlvEntry = _reflection.GeneratedProtocolMessageType('DestTlvEntry', (_message.Message,), dict(
    DESCRIPTOR = _SENDPAYMENTREQUEST_DESTTLVENTRY,
    __module__ = 'routerrpc.router_pb2'
    # @@protoc_insertion_point(class_scope:routerrpc.SendPaymentRequest.DestTlvEntry)
    ))
  ,
  DESCRIPTOR = _SENDPAYMENTREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendPaymentRequest)
  ))
_sym_db.RegisterMessage(SendPaymentRequest)
_sym_db.RegisterMessage(SendPaymentRequest.DestTlvEntry)

TrackPaymentRequest = _reflection.GeneratedProtocolMessageType('TrackPaymentRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRACKPAYMENTREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.TrackPaymentRequest)
  ))
_sym_db.RegisterMessage(TrackPaymentRequest)

PaymentStatus = _reflection.GeneratedProtocolMessageType('PaymentStatus', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTSTATUS,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PaymentStatus)
  ))
_sym_db.RegisterMessage(PaymentStatus)

RouteFeeRequest = _reflection.GeneratedProtocolMessageType('RouteFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeRequest)
  ))
_sym_db.RegisterMessage(RouteFeeRequest)

RouteFeeResponse = _reflection.GeneratedProtocolMessageType('RouteFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeResponse)
  ))
_sym_db.RegisterMessage(RouteFeeResponse)

SendToRouteRequest = _reflection.GeneratedProtocolMessageType('SendToRouteRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDTOROUTEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendToRouteRequest)
  ))
_sym_db.RegisterMessage(SendToRouteRequest)

SendToRouteResponse = _reflection.GeneratedProtocolMessageType('SendToRouteResponse', (_message.Message,), dict(
  DESCRIPTOR = _SENDTOROUTERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendToRouteResponse)
  ))
_sym_db.RegisterMessage(SendToRouteResponse)

Failure = _reflection.GeneratedProtocolMessageType('Failure', (_message.Message,), dict(
  DESCRIPTOR = _FAILURE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.Failure)
  ))
_sym_db.RegisterMessage(Failure)

ChannelUpdate = _reflection.GeneratedProtocolMessageType('ChannelUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELUPDATE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ChannelUpdate)
  ))
_sym_db.RegisterMessage(ChannelUpdate)

ResetMissionControlRequest = _reflection.GeneratedProtocolMessageType('ResetMissionControlRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESETMISSIONCONTROLREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ResetMissionControlRequest)
  ))
_sym_db.RegisterMessage(ResetMissionControlRequest)

ResetMissionControlResponse = _reflection.GeneratedProtocolMessageType('ResetMissionControlResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESETMISSIONCONTROLRESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ResetMissionControlResponse)
  ))
_sym_db.RegisterMessage(ResetMissionControlResponse)

QueryMissionControlRequest = _reflection.GeneratedProtocolMessageType('QueryMissionControlRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUERYMISSIONCONTROLREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryMissionControlRequest)
  ))
_sym_db.RegisterMessage(QueryMissionControlRequest)

QueryMissionControlResponse = _reflection.GeneratedProtocolMessageType('QueryMissionControlResponse', (_message.Message,), dict(
  DESCRIPTOR = _QUERYMISSIONCONTROLRESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryMissionControlResponse)
  ))
_sym_db.RegisterMessage(QueryMissionControlResponse)

NodeHistory = _reflection.GeneratedProtocolMessageType('NodeHistory', (_message.Message,), dict(
  DESCRIPTOR = _NODEHISTORY,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.NodeHistory)
  ))
_sym_db.RegisterMessage(NodeHistory)

PairHistory = _reflection.GeneratedProtocolMessageType('PairHistory', (_message.Message,), dict(
  DESCRIPTOR = _PAIRHISTORY,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PairHistory)
  ))
_sym_db.RegisterMessage(PairHistory)

BuildRouteRequest = _reflection.GeneratedProtocolMessageType('BuildRouteRequest', (_message.Message,), dict(
  DESCRIPTOR = _BUILDROUTEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.BuildRouteRequest)
  ))
_sym_db.RegisterMessage(BuildRouteRequest)

BuildRouteResponse = _reflection.GeneratedProtocolMessageType('BuildRouteResponse', (_message.Message,), dict(
  DESCRIPTOR = _BUILDROUTERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.BuildRouteResponse)
  ))
_sym_db.RegisterMessage(BuildRouteResponse)


DESCRIPTOR._options = None
_SENDPAYMENTREQUEST_DESTTLVENTRY._options = None

_ROUTER = _descriptor.ServiceDescriptor(
  name='Router',
  full_name='routerrpc.Router',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2964,
  serialized_end=3556,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendPayment',
    full_name='routerrpc.Router.SendPayment',
    index=0,
    containing_service=None,
    input_type=_SENDPAYMENTREQUEST,
    output_type=_PAYMENTSTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TrackPayment',
    full_name='routerrpc.Router.TrackPayment',
    index=1,
    containing_service=None,
    input_type=_TRACKPAYMENTREQUEST,
    output_type=_PAYMENTSTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateRouteFee',
    full_name='routerrpc.Router.EstimateRouteFee',
    index=2,
    containing_service=None,
    input_type=_ROUTEFEEREQUEST,
    output_type=_ROUTEFEERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendToRoute',
    full_name='routerrpc.Router.SendToRoute',
    index=3,
    containing_service=None,
    input_type=_SENDTOROUTEREQUEST,
    output_type=_SENDTOROUTERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ResetMissionControl',
    full_name='routerrpc.Router.ResetMissionControl',
    index=4,
    containing_service=None,
    input_type=_RESETMISSIONCONTROLREQUEST,
    output_type=_RESETMISSIONCONTROLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='QueryMissionControl',
    full_name='routerrpc.Router.QueryMissionControl',
    index=5,
    containing_service=None,
    input_type=_QUERYMISSIONCONTROLREQUEST,
    output_type=_QUERYMISSIONCONTROLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BuildRoute',
    full_name='routerrpc.Router.BuildRoute',
    index=6,
    containing_service=None,
    input_type=_BUILDROUTEREQUEST,
    output_type=_BUILDROUTERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROUTER)

DESCRIPTOR.services_by_name['Router'] = _ROUTER

# @@protoc_insertion_point(module_scope)
