# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: autopilotrpc/autopilot.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='autopilotrpc/autopilot.proto',
  package='autopilotrpc',
  syntax='proto3',
  serialized_options=_b('Z1github.com/lncm/lnd-rpc/v0.8.2/lnrpc/autopilotrpc'),
  serialized_pb=_b('\n\x1c\x61utopilotrpc/autopilot.proto\x12\x0c\x61utopilotrpc\"\x0f\n\rStatusRequest\"(\n\x0eStatusResponse\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\"-\n\x13ModifyStatusRequest\x12\x16\n\x06\x65nable\x18\x01 \x01(\x08R\x06\x65nable\"\x16\n\x14ModifyStatusResponse\"T\n\x12QueryScoresRequest\x12\x18\n\x07pubkeys\x18\x01 \x03(\tR\x07pubkeys\x12$\n\x12ignore_local_state\x18\x02 \x01(\x08R\x08no_state\"\x9a\x02\n\x13QueryScoresResponse\x12K\n\x07results\x18\x01 \x03(\x0b\x32\x31.autopilotrpc.QueryScoresResponse.HeuristicResultR\x07results\x1a\xb5\x01\n\x0fHeuristicResult\x12\x1c\n\theuristic\x18\x01 \x01(\tR\theuristic\x12U\n\x06scores\x18\x02 \x03(\x0b\x32=.autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntryR\x06scores\x1a-\n\x0bScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\xa3\x01\n\x10SetScoresRequest\x12\x1c\n\theuristic\x18\x01 \x01(\tR\theuristic\x12\x42\n\x06scores\x18\x02 \x03(\x0b\x32*.autopilotrpc.SetScoresRequest.ScoresEntryR\x06scores\x1a-\n\x0bScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x13\n\x11SetScoresResponse2\xc9\x02\n\tAutopilot\x12\x43\n\x06Status\x12\x1b.autopilotrpc.StatusRequest\x1a\x1c.autopilotrpc.StatusResponse\x12U\n\x0cModifyStatus\x12!.autopilotrpc.ModifyStatusRequest\x1a\".autopilotrpc.ModifyStatusResponse\x12R\n\x0bQueryScores\x12 .autopilotrpc.QueryScoresRequest\x1a!.autopilotrpc.QueryScoresResponse\x12L\n\tSetScores\x12\x1e.autopilotrpc.SetScoresRequest\x1a\x1f.autopilotrpc.SetScoresResponseB3Z1github.com/lncm/lnd-rpc/v0.8.2/lnrpc/autopilotrpcb\x06proto3')
)




_STATUSREQUEST = _descriptor.Descriptor(
  name='StatusRequest',
  full_name='autopilotrpc.StatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=61,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='autopilotrpc.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='autopilotrpc.StatusResponse.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='active', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=103,
)


_MODIFYSTATUSREQUEST = _descriptor.Descriptor(
  name='ModifyStatusRequest',
  full_name='autopilotrpc.ModifyStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='autopilotrpc.ModifyStatusRequest.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enable', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=150,
)


_MODIFYSTATUSRESPONSE = _descriptor.Descriptor(
  name='ModifyStatusResponse',
  full_name='autopilotrpc.ModifyStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=174,
)


_QUERYSCORESREQUEST = _descriptor.Descriptor(
  name='QueryScoresRequest',
  full_name='autopilotrpc.QueryScoresRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkeys', full_name='autopilotrpc.QueryScoresRequest.pubkeys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubkeys', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignore_local_state', full_name='autopilotrpc.QueryScoresRequest.ignore_local_state', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='no_state', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=260,
)


_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY = _descriptor.Descriptor(
  name='ScoresEntry',
  full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=545,
)

_QUERYSCORESRESPONSE_HEURISTICRESULT = _descriptor.Descriptor(
  name='HeuristicResult',
  full_name='autopilotrpc.QueryScoresResponse.HeuristicResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heuristic', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.heuristic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='heuristic', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='autopilotrpc.QueryScoresResponse.HeuristicResult.scores', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scores', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=545,
)

_QUERYSCORESRESPONSE = _descriptor.Descriptor(
  name='QueryScoresResponse',
  full_name='autopilotrpc.QueryScoresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='autopilotrpc.QueryScoresResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='results', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSCORESRESPONSE_HEURISTICRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=545,
)


_SETSCORESREQUEST_SCORESENTRY = _descriptor.Descriptor(
  name='ScoresEntry',
  full_name='autopilotrpc.SetScoresRequest.ScoresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='autopilotrpc.SetScoresRequest.ScoresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='autopilotrpc.SetScoresRequest.ScoresEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=545,
)

_SETSCORESREQUEST = _descriptor.Descriptor(
  name='SetScoresRequest',
  full_name='autopilotrpc.SetScoresRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heuristic', full_name='autopilotrpc.SetScoresRequest.heuristic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='heuristic', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='autopilotrpc.SetScoresRequest.scores', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scores', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SETSCORESREQUEST_SCORESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=711,
)


_SETSCORESRESPONSE = _descriptor.Descriptor(
  name='SetScoresResponse',
  full_name='autopilotrpc.SetScoresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=732,
)

_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY.containing_type = _QUERYSCORESRESPONSE_HEURISTICRESULT
_QUERYSCORESRESPONSE_HEURISTICRESULT.fields_by_name['scores'].message_type = _QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY
_QUERYSCORESRESPONSE_HEURISTICRESULT.containing_type = _QUERYSCORESRESPONSE
_QUERYSCORESRESPONSE.fields_by_name['results'].message_type = _QUERYSCORESRESPONSE_HEURISTICRESULT
_SETSCORESREQUEST_SCORESENTRY.containing_type = _SETSCORESREQUEST
_SETSCORESREQUEST.fields_by_name['scores'].message_type = _SETSCORESREQUEST_SCORESENTRY
DESCRIPTOR.message_types_by_name['StatusRequest'] = _STATUSREQUEST
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['ModifyStatusRequest'] = _MODIFYSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ModifyStatusResponse'] = _MODIFYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['QueryScoresRequest'] = _QUERYSCORESREQUEST
DESCRIPTOR.message_types_by_name['QueryScoresResponse'] = _QUERYSCORESRESPONSE
DESCRIPTOR.message_types_by_name['SetScoresRequest'] = _SETSCORESREQUEST
DESCRIPTOR.message_types_by_name['SetScoresResponse'] = _SETSCORESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATUSREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.StatusRequest)
  ))
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATUSRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.StatusResponse)
  ))
_sym_db.RegisterMessage(StatusResponse)

ModifyStatusRequest = _reflection.GeneratedProtocolMessageType('ModifyStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYSTATUSREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.ModifyStatusRequest)
  ))
_sym_db.RegisterMessage(ModifyStatusRequest)

ModifyStatusResponse = _reflection.GeneratedProtocolMessageType('ModifyStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYSTATUSRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.ModifyStatusResponse)
  ))
_sym_db.RegisterMessage(ModifyStatusResponse)

QueryScoresRequest = _reflection.GeneratedProtocolMessageType('QueryScoresRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUERYSCORESREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresRequest)
  ))
_sym_db.RegisterMessage(QueryScoresRequest)

QueryScoresResponse = _reflection.GeneratedProtocolMessageType('QueryScoresResponse', (_message.Message,), dict(

  HeuristicResult = _reflection.GeneratedProtocolMessageType('HeuristicResult', (_message.Message,), dict(

    ScoresEntry = _reflection.GeneratedProtocolMessageType('ScoresEntry', (_message.Message,), dict(
      DESCRIPTOR = _QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY,
      __module__ = 'autopilotrpc.autopilot_pb2'
      # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresResponse.HeuristicResult.ScoresEntry)
      ))
    ,
    DESCRIPTOR = _QUERYSCORESRESPONSE_HEURISTICRESULT,
    __module__ = 'autopilotrpc.autopilot_pb2'
    # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresResponse.HeuristicResult)
    ))
  ,
  DESCRIPTOR = _QUERYSCORESRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.QueryScoresResponse)
  ))
_sym_db.RegisterMessage(QueryScoresResponse)
_sym_db.RegisterMessage(QueryScoresResponse.HeuristicResult)
_sym_db.RegisterMessage(QueryScoresResponse.HeuristicResult.ScoresEntry)

SetScoresRequest = _reflection.GeneratedProtocolMessageType('SetScoresRequest', (_message.Message,), dict(

  ScoresEntry = _reflection.GeneratedProtocolMessageType('ScoresEntry', (_message.Message,), dict(
    DESCRIPTOR = _SETSCORESREQUEST_SCORESENTRY,
    __module__ = 'autopilotrpc.autopilot_pb2'
    # @@protoc_insertion_point(class_scope:autopilotrpc.SetScoresRequest.ScoresEntry)
    ))
  ,
  DESCRIPTOR = _SETSCORESREQUEST,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.SetScoresRequest)
  ))
_sym_db.RegisterMessage(SetScoresRequest)
_sym_db.RegisterMessage(SetScoresRequest.ScoresEntry)

SetScoresResponse = _reflection.GeneratedProtocolMessageType('SetScoresResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSCORESRESPONSE,
  __module__ = 'autopilotrpc.autopilot_pb2'
  # @@protoc_insertion_point(class_scope:autopilotrpc.SetScoresResponse)
  ))
_sym_db.RegisterMessage(SetScoresResponse)


DESCRIPTOR._options = None
_QUERYSCORESRESPONSE_HEURISTICRESULT_SCORESENTRY._options = None
_SETSCORESREQUEST_SCORESENTRY._options = None

_AUTOPILOT = _descriptor.ServiceDescriptor(
  name='Autopilot',
  full_name='autopilotrpc.Autopilot',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=735,
  serialized_end=1064,
  methods=[
  _descriptor.MethodDescriptor(
    name='Status',
    full_name='autopilotrpc.Autopilot.Status',
    index=0,
    containing_service=None,
    input_type=_STATUSREQUEST,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyStatus',
    full_name='autopilotrpc.Autopilot.ModifyStatus',
    index=1,
    containing_service=None,
    input_type=_MODIFYSTATUSREQUEST,
    output_type=_MODIFYSTATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='QueryScores',
    full_name='autopilotrpc.Autopilot.QueryScores',
    index=2,
    containing_service=None,
    input_type=_QUERYSCORESREQUEST,
    output_type=_QUERYSCORESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetScores',
    full_name='autopilotrpc.Autopilot.SetScores',
    index=3,
    containing_service=None,
    input_type=_SETSCORESREQUEST,
    output_type=_SETSCORESRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTOPILOT)

DESCRIPTOR.services_by_name['Autopilot'] = _AUTOPILOT

# @@protoc_insertion_point(module_scope)
