# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chainrpc/chainnotifier.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='chainrpc/chainnotifier.proto',
  package='chainrpc',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1c\x63hainrpc/chainnotifier.proto\x12\x08\x63hainrpc\"S\n\x0b\x43onfRequest\x12\x0c\n\x04txid\x18\x01 \x01(\x0c\x12\x0e\n\x06script\x18\x02 \x01(\x0c\x12\x11\n\tnum_confs\x18\x03 \x01(\r\x12\x13\n\x0bheight_hint\x18\x04 \x01(\r\"Y\n\x0b\x43onfDetails\x12\x0e\n\x06raw_tx\x18\x01 \x01(\x0c\x12\x12\n\nblock_hash\x18\x02 \x01(\x0c\x12\x14\n\x0c\x62lock_height\x18\x03 \x01(\r\x12\x10\n\x08tx_index\x18\x04 \x01(\r\"\x07\n\x05Reorg\"]\n\tConfEvent\x12%\n\x04\x63onf\x18\x01 \x01(\x0b\x32\x15.chainrpc.ConfDetailsH\x00\x12 \n\x05reorg\x18\x02 \x01(\x0b\x32\x0f.chainrpc.ReorgH\x00\x42\x07\n\x05\x65vent\"\'\n\x08Outpoint\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\r\n\x05index\x18\x02 \x01(\r\"Y\n\x0cSpendRequest\x12$\n\x08outpoint\x18\x01 \x01(\x0b\x32\x12.chainrpc.Outpoint\x12\x0e\n\x06script\x18\x02 \x01(\x0c\x12\x13\n\x0bheight_hint\x18\x03 \x01(\r\"\xa7\x01\n\x0cSpendDetails\x12-\n\x11spending_outpoint\x18\x01 \x01(\x0b\x32\x12.chainrpc.Outpoint\x12\x17\n\x0fraw_spending_tx\x18\x02 \x01(\x0c\x12\x18\n\x10spending_tx_hash\x18\x03 \x01(\x0c\x12\x1c\n\x14spending_input_index\x18\x04 \x01(\r\x12\x17\n\x0fspending_height\x18\x05 \x01(\r\"`\n\nSpendEvent\x12\'\n\x05spend\x18\x01 \x01(\x0b\x32\x16.chainrpc.SpendDetailsH\x00\x12 \n\x05reorg\x18\x02 \x01(\x0b\x32\x0f.chainrpc.ReorgH\x00\x42\x07\n\x05\x65vent\"*\n\nBlockEpoch\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06height\x18\x02 \x01(\r2\xe7\x01\n\rChainNotifier\x12I\n\x19RegisterConfirmationsNtfn\x12\x15.chainrpc.ConfRequest\x1a\x13.chainrpc.ConfEvent0\x01\x12\x43\n\x11RegisterSpendNtfn\x12\x16.chainrpc.SpendRequest\x1a\x14.chainrpc.SpendEvent0\x01\x12\x46\n\x16RegisterBlockEpochNtfn\x12\x14.chainrpc.BlockEpoch\x1a\x14.chainrpc.BlockEpoch0\x01\x62\x06proto3')
)




_CONFREQUEST = _descriptor.Descriptor(
  name='ConfRequest',
  full_name='chainrpc.ConfRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txid', full_name='chainrpc.ConfRequest.txid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='chainrpc.ConfRequest.script', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_confs', full_name='chainrpc.ConfRequest.num_confs', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height_hint', full_name='chainrpc.ConfRequest.height_hint', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=125,
)


_CONFDETAILS = _descriptor.Descriptor(
  name='ConfDetails',
  full_name='chainrpc.ConfDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_tx', full_name='chainrpc.ConfDetails.raw_tx', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_hash', full_name='chainrpc.ConfDetails.block_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_height', full_name='chainrpc.ConfDetails.block_height', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_index', full_name='chainrpc.ConfDetails.tx_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=216,
)


_REORG = _descriptor.Descriptor(
  name='Reorg',
  full_name='chainrpc.Reorg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=225,
)


_CONFEVENT = _descriptor.Descriptor(
  name='ConfEvent',
  full_name='chainrpc.ConfEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conf', full_name='chainrpc.ConfEvent.conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reorg', full_name='chainrpc.ConfEvent.reorg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='chainrpc.ConfEvent.event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=227,
  serialized_end=320,
)


_OUTPOINT = _descriptor.Descriptor(
  name='Outpoint',
  full_name='chainrpc.Outpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='chainrpc.Outpoint.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='chainrpc.Outpoint.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=361,
)


_SPENDREQUEST = _descriptor.Descriptor(
  name='SpendRequest',
  full_name='chainrpc.SpendRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outpoint', full_name='chainrpc.SpendRequest.outpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='chainrpc.SpendRequest.script', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height_hint', full_name='chainrpc.SpendRequest.height_hint', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=452,
)


_SPENDDETAILS = _descriptor.Descriptor(
  name='SpendDetails',
  full_name='chainrpc.SpendDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spending_outpoint', full_name='chainrpc.SpendDetails.spending_outpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_spending_tx', full_name='chainrpc.SpendDetails.raw_spending_tx', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spending_tx_hash', full_name='chainrpc.SpendDetails.spending_tx_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spending_input_index', full_name='chainrpc.SpendDetails.spending_input_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spending_height', full_name='chainrpc.SpendDetails.spending_height', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=622,
)


_SPENDEVENT = _descriptor.Descriptor(
  name='SpendEvent',
  full_name='chainrpc.SpendEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spend', full_name='chainrpc.SpendEvent.spend', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reorg', full_name='chainrpc.SpendEvent.reorg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='chainrpc.SpendEvent.event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=624,
  serialized_end=720,
)


_BLOCKEPOCH = _descriptor.Descriptor(
  name='BlockEpoch',
  full_name='chainrpc.BlockEpoch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='chainrpc.BlockEpoch.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='chainrpc.BlockEpoch.height', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=764,
)

_CONFEVENT.fields_by_name['conf'].message_type = _CONFDETAILS
_CONFEVENT.fields_by_name['reorg'].message_type = _REORG
_CONFEVENT.oneofs_by_name['event'].fields.append(
  _CONFEVENT.fields_by_name['conf'])
_CONFEVENT.fields_by_name['conf'].containing_oneof = _CONFEVENT.oneofs_by_name['event']
_CONFEVENT.oneofs_by_name['event'].fields.append(
  _CONFEVENT.fields_by_name['reorg'])
_CONFEVENT.fields_by_name['reorg'].containing_oneof = _CONFEVENT.oneofs_by_name['event']
_SPENDREQUEST.fields_by_name['outpoint'].message_type = _OUTPOINT
_SPENDDETAILS.fields_by_name['spending_outpoint'].message_type = _OUTPOINT
_SPENDEVENT.fields_by_name['spend'].message_type = _SPENDDETAILS
_SPENDEVENT.fields_by_name['reorg'].message_type = _REORG
_SPENDEVENT.oneofs_by_name['event'].fields.append(
  _SPENDEVENT.fields_by_name['spend'])
_SPENDEVENT.fields_by_name['spend'].containing_oneof = _SPENDEVENT.oneofs_by_name['event']
_SPENDEVENT.oneofs_by_name['event'].fields.append(
  _SPENDEVENT.fields_by_name['reorg'])
_SPENDEVENT.fields_by_name['reorg'].containing_oneof = _SPENDEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['ConfRequest'] = _CONFREQUEST
DESCRIPTOR.message_types_by_name['ConfDetails'] = _CONFDETAILS
DESCRIPTOR.message_types_by_name['Reorg'] = _REORG
DESCRIPTOR.message_types_by_name['ConfEvent'] = _CONFEVENT
DESCRIPTOR.message_types_by_name['Outpoint'] = _OUTPOINT
DESCRIPTOR.message_types_by_name['SpendRequest'] = _SPENDREQUEST
DESCRIPTOR.message_types_by_name['SpendDetails'] = _SPENDDETAILS
DESCRIPTOR.message_types_by_name['SpendEvent'] = _SPENDEVENT
DESCRIPTOR.message_types_by_name['BlockEpoch'] = _BLOCKEPOCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfRequest = _reflection.GeneratedProtocolMessageType('ConfRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONFREQUEST,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.ConfRequest)
  ))
_sym_db.RegisterMessage(ConfRequest)

ConfDetails = _reflection.GeneratedProtocolMessageType('ConfDetails', (_message.Message,), dict(
  DESCRIPTOR = _CONFDETAILS,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.ConfDetails)
  ))
_sym_db.RegisterMessage(ConfDetails)

Reorg = _reflection.GeneratedProtocolMessageType('Reorg', (_message.Message,), dict(
  DESCRIPTOR = _REORG,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.Reorg)
  ))
_sym_db.RegisterMessage(Reorg)

ConfEvent = _reflection.GeneratedProtocolMessageType('ConfEvent', (_message.Message,), dict(
  DESCRIPTOR = _CONFEVENT,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.ConfEvent)
  ))
_sym_db.RegisterMessage(ConfEvent)

Outpoint = _reflection.GeneratedProtocolMessageType('Outpoint', (_message.Message,), dict(
  DESCRIPTOR = _OUTPOINT,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.Outpoint)
  ))
_sym_db.RegisterMessage(Outpoint)

SpendRequest = _reflection.GeneratedProtocolMessageType('SpendRequest', (_message.Message,), dict(
  DESCRIPTOR = _SPENDREQUEST,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.SpendRequest)
  ))
_sym_db.RegisterMessage(SpendRequest)

SpendDetails = _reflection.GeneratedProtocolMessageType('SpendDetails', (_message.Message,), dict(
  DESCRIPTOR = _SPENDDETAILS,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.SpendDetails)
  ))
_sym_db.RegisterMessage(SpendDetails)

SpendEvent = _reflection.GeneratedProtocolMessageType('SpendEvent', (_message.Message,), dict(
  DESCRIPTOR = _SPENDEVENT,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.SpendEvent)
  ))
_sym_db.RegisterMessage(SpendEvent)

BlockEpoch = _reflection.GeneratedProtocolMessageType('BlockEpoch', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKEPOCH,
  __module__ = 'chainrpc.chainnotifier_pb2'
  # @@protoc_insertion_point(class_scope:chainrpc.BlockEpoch)
  ))
_sym_db.RegisterMessage(BlockEpoch)



_CHAINNOTIFIER = _descriptor.ServiceDescriptor(
  name='ChainNotifier',
  full_name='chainrpc.ChainNotifier',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=767,
  serialized_end=998,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterConfirmationsNtfn',
    full_name='chainrpc.ChainNotifier.RegisterConfirmationsNtfn',
    index=0,
    containing_service=None,
    input_type=_CONFREQUEST,
    output_type=_CONFEVENT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterSpendNtfn',
    full_name='chainrpc.ChainNotifier.RegisterSpendNtfn',
    index=1,
    containing_service=None,
    input_type=_SPENDREQUEST,
    output_type=_SPENDEVENT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterBlockEpochNtfn',
    full_name='chainrpc.ChainNotifier.RegisterBlockEpochNtfn',
    index=2,
    containing_service=None,
    input_type=_BLOCKEPOCH,
    output_type=_BLOCKEPOCH,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHAINNOTIFIER)

DESCRIPTOR.services_by_name['ChainNotifier'] = _CHAINNOTIFIER

# @@protoc_insertion_point(module_scope)
